### 自用模块nightHua
 
#### 安装
 
> pip install nightHua
 
#### 使用

```python
from nightHua import Usual
from nightHua import Config
```
#### 版本更新内容
>##### 1.1:
>> 添加了Config类<br>
>> Usual类中添加了getTimeStr,StrOfSize函数
>##### 1.1.1:
>> bug修复
>##### 1.1.2:
>> bug修复
